@@ -18,51 +18,45 @@ Usage::
     list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
     ```
 """
-import sys
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_cloud9.literals import Permissions
 from mypy_boto3_cloud9.type_defs import (
     DescribeEnvironmentMembershipsResultTypeDef,
     ListEnvironmentsResultTypeDef,
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("DescribeEnvironmentMembershipsPaginator", "ListEnvironmentsPaginator")
 
 
 class DescribeEnvironmentMembershipsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEnvironmentMemberships documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
+    [Paginator.DescribeEnvironmentMemberships documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
     """
 
     def paginate(
         self,
         userArn: str = None,
         environmentId: str = None,
-        permissions: List[Literal["owner", "read-write", "read-only"]] = None,
+        permissions: List[Permissions] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEnvironmentMembershipsResultTypeDef]:
         """
-        [DescribeEnvironmentMemberships.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships.paginate)
+        [DescribeEnvironmentMemberships.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships.paginate)
         """
 
 
 class ListEnvironmentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
+    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListEnvironmentsResultTypeDef]:
         """
-        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments.paginate)
+        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments.paginate)
         """
