@@ -13,10 +13,15 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_cloud9.literals import (
+    ConnectionType,
+    EnvironmentLifecycleStatus,
+    EnvironmentStatus,
+    EnvironmentType,
+    ManagedCredentialsStatus,
+    Permissions,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -41,22 +46,13 @@ __all__ = (
 
 EnvironmentLifecycleTypeDef = TypedDict(
     "EnvironmentLifecycleTypeDef",
-    {
-        "status": Literal["CREATING", "CREATED", "CREATE_FAILED", "DELETING", "DELETE_FAILED"],
-        "reason": str,
-        "failureResource": str,
-    },
+    {"status": EnvironmentLifecycleStatus, "reason": str, "failureResource": str},
     total=False,
 )
 
 _RequiredEnvironmentMemberTypeDef = TypedDict(
     "_RequiredEnvironmentMemberTypeDef",
-    {
-        "permissions": Literal["owner", "read-write", "read-only"],
-        "userId": str,
-        "userArn": str,
-        "environmentId": str,
-    },
+    {"permissions": Permissions, "userId": str, "userArn": str, "environmentId": str},
 )
 _OptionalEnvironmentMemberTypeDef = TypedDict(
     "_OptionalEnvironmentMemberTypeDef", {"lastAccess": datetime}, total=False
@@ -70,7 +66,7 @@ class EnvironmentMemberTypeDef(
 
 
 _RequiredEnvironmentTypeDef = TypedDict(
-    "_RequiredEnvironmentTypeDef", {"type": Literal["ssh", "ec2"], "arn": str, "ownerArn": str}
+    "_RequiredEnvironmentTypeDef", {"type": EnvironmentType, "arn": str, "ownerArn": str}
 )
 _OptionalEnvironmentTypeDef = TypedDict(
     "_OptionalEnvironmentTypeDef",
@@ -78,21 +74,9 @@ _OptionalEnvironmentTypeDef = TypedDict(
         "id": str,
         "name": str,
         "description": str,
-        "connectionType": Literal["CONNECT_SSH", "CONNECT_SSM"],
+        "connectionType": ConnectionType,
         "lifecycle": "EnvironmentLifecycleTypeDef",
-        "managedCredentialsStatus": Literal[
-            "ENABLED_ON_CREATE",
-            "ENABLED_BY_OWNER",
-            "DISABLED_BY_DEFAULT",
-            "DISABLED_BY_OWNER",
-            "DISABLED_BY_COLLABORATOR",
-            "PENDING_REMOVAL_BY_COLLABORATOR",
-            "PENDING_START_REMOVAL_BY_COLLABORATOR",
-            "PENDING_REMOVAL_BY_OWNER",
-            "PENDING_START_REMOVAL_BY_OWNER",
-            "FAILED_REMOVAL_BY_COLLABORATOR",
-            "FAILED_REMOVAL_BY_OWNER",
-        ],
+        "managedCredentialsStatus": ManagedCredentialsStatus,
     },
     total=False,
 )
@@ -119,13 +103,7 @@ DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
 )
 
 DescribeEnvironmentStatusResultTypeDef = TypedDict(
-    "DescribeEnvironmentStatusResultTypeDef",
-    {
-        "status": Literal[
-            "error", "creating", "connecting", "ready", "stopping", "stopped", "deleting"
-        ],
-        "message": str,
-    },
+    "DescribeEnvironmentStatusResultTypeDef", {"status": EnvironmentStatus, "message": str}
 )
 
 DescribeEnvironmentsResultTypeDef = TypedDict(
